Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2018-07-15 00:49:00 +0300
committerCampbell Barton <ideasman42@gmail.com>2018-07-15 00:49:00 +0300
commit5ebebcfbfff4c218ab4101ee7f6a66617ee9b01f (patch)
tree86f319a9291847c2608bfd0b89bae3d504e378cf /source/blender/editors/gizmo_library/gizmo_library_presets.c
parentcd1600413246a62156441f6e7910489b19ae5a28 (diff)
WM: rename manipulator to gizmo internally
Diffstat (limited to 'source/blender/editors/gizmo_library/gizmo_library_presets.c')
-rw-r--r--source/blender/editors/gizmo_library/gizmo_library_presets.c44
1 files changed, 22 insertions, 22 deletions
diff --git a/source/blender/editors/gizmo_library/gizmo_library_presets.c b/source/blender/editors/gizmo_library/gizmo_library_presets.c
index d58e0c9dc85..8a6b92e48d6 100644
--- a/source/blender/editors/gizmo_library/gizmo_library_presets.c
+++ b/source/blender/editors/gizmo_library/gizmo_library_presets.c
@@ -21,9 +21,9 @@
/** \file blender/editors/gizmo_library/gizmo_library_presets.c
* \ingroup wm
*
* \name Manipulator Lib Presets
*
* \brief Preset shapes that can be drawn from any manipulator type.
*/
#include "MEM_guardedalloc.h"
@@ -57,7 +57,7 @@
#include "ED_gizmo_library.h" /* own include */
#include "gizmo_library_intern.h" /* own include */
/* TODO, this is to be used by RNA. might move to ED_manipulator_library */
/**
* Given a single axis, orient the matrix to a different direction.
@@ -80,15 +80,15 @@ static void single_axis_convert(
/**
* Use for all geometry.
*/
-static void ed_manipulator_draw_preset_geometry(
- const struct wmManipulator *mpr, float mat[4][4], int select_id,
- const ManipulatorGeomInfo *info)
+static void ed_gizmo_draw_preset_geometry(
+ const struct wmGizmo *mpr, float mat[4][4], int select_id,
+ const GizmoGeomInfo *info)
{
const bool is_select = (select_id != -1);
- const bool is_highlight = is_select && (mpr->state & WM_MANIPULATOR_STATE_HIGHLIGHT) != 0;
+ const bool is_highlight = is_select && (mpr->state & WM_GIZMO_STATE_HIGHLIGHT) != 0;
float color[4];
- manipulator_color_get(mpr, is_highlight, color);
+ gizmo_color_get(mpr, is_highlight, color);
if (is_select) {
GPU_select_load_id(select_id);
@@ -96,7 +96,7 @@ static void ed_manipulator_draw_preset_geometry(
gpuPushMatrix();
gpuMultMatrix(mat);
- wm_manipulator_geometryinfo_draw(info, is_select, color);
+ wm_gizmo_geometryinfo_draw(info, is_select, color);
gpuPopMatrix();
if (is_select) {
@@ -104,36 +104,36 @@ static void ed_manipulator_draw_preset_geometry(
}
}
-void ED_manipulator_draw_preset_box(
- const struct wmManipulator *mpr, float mat[4][4], int select_id)
+void ED_gizmo_draw_preset_box(
+ const struct wmGizmo *mpr, float mat[4][4], int select_id)
{
- ed_manipulator_draw_preset_geometry(mpr, mat, select_id, &wm_manipulator_geom_data_cube);
+ ed_gizmo_draw_preset_geometry(mpr, mat, select_id, &wm_gizmo_geom_data_cube);
}
-void ED_manipulator_draw_preset_arrow(
- const struct wmManipulator *mpr, float mat[4][4], int axis, int select_id)
+void ED_gizmo_draw_preset_arrow(
+ const struct wmGizmo *mpr, float mat[4][4], int axis, int select_id)
{
float mat_rotate[4][4];
single_axis_convert(OB_POSZ, mat, axis, mat_rotate);
- ed_manipulator_draw_preset_geometry(mpr, mat_rotate, select_id, &wm_manipulator_geom_data_arrow);
+ ed_gizmo_draw_preset_geometry(mpr, mat_rotate, select_id, &wm_gizmo_geom_data_arrow);
}
-void ED_manipulator_draw_preset_circle(
- const struct wmManipulator *mpr, float mat[4][4], int axis, int select_id)
+void ED_gizmo_draw_preset_circle(
+ const struct wmGizmo *mpr, float mat[4][4], int axis, int select_id)
{
float mat_rotate[4][4];
single_axis_convert(OB_POSZ, mat, axis, mat_rotate);
- ed_manipulator_draw_preset_geometry(mpr, mat_rotate, select_id, &wm_manipulator_geom_data_dial);
+ ed_gizmo_draw_preset_geometry(mpr, mat_rotate, select_id, &wm_gizmo_geom_data_dial);
}
-void ED_manipulator_draw_preset_facemap(
- const bContext *C, const struct wmManipulator *mpr, struct Scene *scene, Object *ob, const int facemap, int select_id)
+void ED_gizmo_draw_preset_facemap(
+ const bContext *C, const struct wmGizmo *mpr, struct Scene *scene, Object *ob, const int facemap, int select_id)
{
const bool is_select = (select_id != -1);
- const bool is_highlight = is_select && (mpr->state & WM_MANIPULATOR_STATE_HIGHLIGHT) != 0;
+ const bool is_highlight = is_select && (mpr->state & WM_GIZMO_STATE_HIGHLIGHT) != 0;
float color[4];
- manipulator_color_get(mpr, is_highlight, color);
+ gizmo_color_get(mpr, is_highlight, color);
if (is_select) {
GPU_select_load_id(select_id);
@@ -21,9 +21,9 @@
* \ingroup wm
*
- * \name Manipulator Lib Presets
+ * \name Gizmo Lib Presets
*
@@ -21,9 +21,9 @@
*
- * \brief Preset shapes that can be drawn from any manipulator type.
+ * \brief Preset shapes that can be drawn from any gizmo type.
*/
#include "MEM_guardedalloc.h"
@@ -57,7 +57,7 @@
#include "ED_gizmo_library.h" /* own include */
#include "gizmo_library_intern.h" /* own include */
-/* TODO, this is to be used by RNA. might move to ED_manipulator_library */
+/* TODO, this is to be used by RNA. might move to ED_gizmo_library */
/**
* Given a single axis, orient the matrix to a different direction.